@@ -113,6 +113,8 @@ class MediaPipeline:
         if fp in info.downloading:
             return wad
 
+        request.headers[
+            "User-Agent"] = "Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1"
         # Download request checking media_to_download hook output first
         info.downloading.add(fp)
         dfd = mustbe_deferred(self.media_to_download, request, info, item)
